@@ -2,7 +2,7 @@
 vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
 */
 /*
-Copyright (c) 2015, iwrite authors
+Copyright (c) 2015-2016, iwrite authors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "mariadb.h"
 
-extern void
+EXTERN void
 iwsql_delete(
   struct mariadb**                      io_mysql)
 {
@@ -50,6 +50,7 @@ iwsql_delete(
     mysql_close((*l_mysql).m_connection);
   }
 
+  free((*l_mysql).m_database);
   free(l_mysql);
 
   (*io_mysql)= 0;
