@@ -2,7 +2,7 @@
 vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
 */
 /*
-Copyright (c) 2015, iwrite authors
+Copyright (c) 2015-2016, iwrite authors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -37,8 +37,23 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <mysql.h>
 #include "iwsql.h"
 
+#ifdef WIN32
+#  ifdef DLL_INTERNAL
+#    define EXTERN extern __declspec(dllexport)
+#  else
+#    define EXTERN extern __declspec(dllimport)
+#  endif
+#else
+#  ifdef __cplusplus
+#    define EXTERN extern "C"
+#  else
+#    define EXTERN extern 
+#  endif
+#endif
+
 struct mariadb
 {
+  char*                                 m_database;
   MYSQL*                                m_connection;
   MYSQL_RES*                            m_result;
   unsigned                              m_tuple;
@@ -47,62 +62,68 @@ struct mariadb
   unsigned                              m_attr_slots;
 };
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-extern void 
+EXTERN void 
 iwsql_attr_delete(
   struct iwsql_attr**                   o_attr,
   unsigned const                        i_slots);
 
-extern void
+EXTERN void
 iwsql_attr_new(
   struct iwsql_attr**                   o_attr,
   unsigned *const                       o_slots,
   struct mariadb*const                  i_mysql);
 
-extern int
+EXTERN int
 iwsql_connect(
   char**                                o_error,
   struct iwsql_aspect const*const       i_aspect,
   struct mariadb*const                  i_mysql);
 
-extern void
+EXTERN void
 iwsql_delete(
   struct mariadb**                      io_mysql);
 
-extern void
+EXTERN void
 iwsql_error(
   char**                                o_error,
   char const*                           i_message,
   MYSQL*const                           i_connection);
 
-extern int
+EXTERN int
 iwsql_exec(
   char**                                o_error,
   char const*                           i_query,
   struct mariadb*const                  io_mysql);
 
-extern void
+EXTERN void
 iwsql_new(
   struct mariadb**                      o_mysql);
 
-extern int
+EXTERN int
 iwsql_next(
   char**                                o_error,
   int*const                             o_eof,
   struct mariadb *const                 i_mysql);
 
-extern void 
+EXTERN void 
 iwsql_result(
   struct iwsql_attr const**             o_attr,
   unsigned*const                        o_slots,
   struct mariadb *const                 i_mysql);
 
-#ifdef __cplusplus
-}
-#endif
+EXTERN int
+iwsql_show_databases(
+  char**                                o_error,
+  char***                               o_list,
+  unsigned*const                        o_slots,
+  struct mariadb *const                 i_mysql);
+
+EXTERN int
+iwsql_show_tables(
+  char**                                o_error,
+  char***                               o_list,
+  unsigned*const                        o_slots,
+  struct mariadb *const                 i_mysql);
 
 #define __mariadb_h__
 #endif
