@@ -2,7 +2,7 @@
 vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
 */
 /*
-Copyright (c) 2015, iwrite authors
+Copyright (c) 2015-2016, iwrite authors
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -30,7 +30,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "sqlite.h"
 
-extern int
+EXTERN int
 iwsql_connect(
   char**                                o_error,
   struct iwsql_aspect const*const       i_aspect,
