@@ -2,7 +2,7 @@
 vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler
 */
 /*
-Copyright (c) 2015, iwrite authors 
+Copyright (c) 2015-2016, iwrite authors 
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -29,16 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "database_config.h"
-
-#ifdef WIN32
-# define DIR_SEP '\\'
-#else
-# include <sys/types.h>
-# include <sys/stat.h>
-# include <unistd.h>
-# include <pwd.h>
-# define DIR_SEP '/'
-#endif
+#include "wallet.h"
 
 extern void
 database_config_assign(
@@ -54,9 +45,14 @@ extern void
 database_config_discharge(
   struct database_config*const          io_config)
 {
+  unsigned                              l_slot;
 
   if ((*io_config).m_aspect)
   {
+    for (l_slot= 0; (*io_config).m_count > l_slot; l_slot++)
+    {
+      database_aspect_discharge(&(*io_config).m_aspect[l_slot]);
+    }
     g_free((*io_config).m_aspect);
   }
 
@@ -73,8 +69,9 @@ database_config_load(
   char const*                           l_configfile;
   gsize                                 l_group_count;
   gchar**                               l_groups;
-  GKeyFile*                             l_key;
   struct database_aspect*               l_aspect;
+  GKeyFile*                             l_key;
+  struct password*                      l_pwd;
   gsize                                 l_slot;
   char*                                 l_value;
 
@@ -119,7 +116,7 @@ database_config_load(
           (1+(*o_config).m_count)*sizeof(struct database_aspect));
 
       l_aspect= &(*o_config).m_aspect[(*o_config).m_count];
-      memset(l_aspect, 0, sizeof(*l_aspect));
+      database_aspect_assign(l_aspect);
       (*o_config).m_count++;
 
       strncpy((*l_aspect).m_tag, l_groups[l_slot], sizeof((*l_aspect).m_tag));
@@ -128,41 +125,57 @@ database_config_load(
       if (l_value)
       {
         strncpy((*l_aspect).m_dbname, l_value, sizeof((*l_aspect).m_dbname));
+        g_free(l_value);
       }
 
       l_value= g_key_file_get_value(l_key, l_groups[l_slot], "driver", 0);
       if (l_value)
       {
         strncpy((*l_aspect).m_driver, l_value, sizeof((*l_aspect).m_driver));
+        g_free(l_value);
       }
 
       l_value= g_key_file_get_value(l_key, l_groups[l_slot], "host", 0);
       if (l_value)
       {
         strncpy((*l_aspect).m_host, l_value, sizeof((*l_aspect).m_host));
+        g_free(l_value);
       }
 
       l_value= g_key_file_get_value(l_key, l_groups[l_slot], "hostaddr", 0);
       if (l_value)
       {
         strncpy((*l_aspect).m_hostaddr, l_value, sizeof((*l_aspect).m_hostaddr));
+        g_free(l_value);
       }
 
       l_value= g_key_file_get_value(l_key, l_groups[l_slot], "port", 0);
       if (l_value)
       {
         strncpy((*l_aspect).m_port, l_value, sizeof((*l_aspect).m_port));
+        g_free(l_value);
       }
 
       l_value= g_key_file_get_value(l_key, l_groups[l_slot], "username", 0);
       if (l_value)
       {
         strncpy((*l_aspect).m_username, l_value, sizeof((*l_aspect).m_username));
+        g_free(l_value);
       }
 
       (*l_aspect).m_prompt_password= g_key_file_get_boolean(l_key, l_groups[l_slot], "prompt_password", 0);
 
-      g_free(l_value);
+      l_pwd= wallet_lookup((*l_aspect).m_tag);
+
+      if (0 == l_pwd)
+      {
+        l_pwd= wallet_lookup("");
+      }
+
+      if (l_pwd)
+      {
+        (*l_aspect).m_password= g_strdup((*l_pwd).m_password);
+      }
 
     }
 
@@ -232,14 +245,56 @@ database_config_delete_group(
 }
 
 extern void
-database_config_save_group(
-  struct database_config*const          io_config,
-  unsigned const                        i_slot)
+database_config_populate_tag(
+  char                                  o_tag[31+1],
+  struct database_config const*const    i_config)
+{
+  int                                   l_rc;
+  unsigned                              l_slot;
+  char                                  l_tag[31+1];
+  unsigned                              l_value;
+
+  memset(o_tag, 0, 32);
+  g_strlcpy(l_tag, DATABASE_CONFIG_DEFAULT_TAG, sizeof(l_tag));
+  l_value= 0;
+
+  do
+  {
+
+    l_rc= -1;
+
+    for (l_slot= 0; (*i_config).m_count > l_slot; l_slot++)
+    {
+      l_rc= strcmp(l_tag, (*i_config).m_aspect[l_slot].m_tag);
+
+      if (0 == l_rc)
+      {
+        break;
+      }
+    }
+
+    if (l_rc)
+    {
+      memcpy(o_tag, l_tag, sizeof(l_tag));
+      break;
+    }
+
+    l_value++;
+    snprintf(l_tag, sizeof(l_tag), "%s%u", DATABASE_CONFIG_DEFAULT_TAG, l_value);
+
+  }while(1);
+
+  return;
+}
+
+extern void
+database_config_save_aspect(
+  struct database_aspect const*const    i_aspect)
 {
   gboolean                              l_bool;
   char const*                           l_configfile;
+  char const*                           l_tag;
   GKeyFile*                             l_key;
-  struct database_aspect *              l_aspect;
 
   l_configfile= get_database_config_filename();
   l_key= 0;
@@ -247,11 +302,13 @@ database_config_save_group(
   do
   {
 
-    l_aspect= &(*io_config).m_aspect[i_slot];
-
-    if (0 == (*l_aspect).m_tag[0])
+    if ((*i_aspect).m_tag[0])
     {
-      g_strlcpy((*l_aspect).m_tag, DATABASE_CONFIG_DEFAULT_TAG, sizeof((*l_aspect).m_tag));
+      l_tag= (*i_aspect).m_tag;
+    }
+    else
+    {
+      l_tag= DATABASE_CONFIG_DEFAULT_TAG;
     }
 
     l_key= g_key_file_new();
@@ -265,45 +322,45 @@ database_config_save_group(
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "driver",
-      (*l_aspect).m_driver);
+      (*i_aspect).m_driver);
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "database",
-      (*l_aspect).m_dbname);
+      (*i_aspect).m_dbname);
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "host",
-      (*l_aspect).m_host);
+      (*i_aspect).m_host);
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "hostaddr",
-      (*l_aspect).m_hostaddr);
+      (*i_aspect).m_hostaddr);
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "port",
-      (*l_aspect).m_port);
+      (*i_aspect).m_port);
 
     g_key_file_set_value(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "username",
-      (*l_aspect).m_username);
+      (*i_aspect).m_username);
 
     g_key_file_set_boolean(
       l_key,
-      (*l_aspect).m_tag,
+      l_tag,
       "prompt_password",
-      (*l_aspect).m_prompt_password);
+      (*i_aspect).m_prompt_password);
 
     l_bool= g_key_file_save_to_file(l_key, l_configfile, 0);
 
