@@ -48,7 +48,6 @@ database_session_connect(
   struct database_session*const         io_session,
   struct database_aspect const*const    i_aspect)
 {
-  struct iwsql_aspect                   l_conn;
   struct driver_config                  l_driver;
   GError*                               l_error;
   int                                   l_exit;
@@ -122,7 +121,41 @@ database_session_connect(
       break;
     }
 
-    l_exit= iwsql_dll_load(&l_error, &(*io_session).m_dll, l_module);
+    l_exit= database_session_connect_module(
+      &l_error,
+      io_session,
+      l_module,
+      i_aspect); 
+
+  }while(0);
+
+  driver_config_discharge(&l_driver);
+
+  if (l_error)
+  {
+    g_propagate_error(o_error, l_error);
+  }
+
+  return l_exit;
+}
+
+extern int
+database_session_connect_module(
+  GError**                              o_error,
+  struct database_session*const         io_session,
+  struct driver_module const*const      i_module,
+  struct database_aspect const*const    i_aspect)
+{
+  struct iwsql_aspect                   l_conn;
+  GError*                               l_error;
+  int                                   l_exit;
+
+  l_error= 0;
+
+  do
+  {
+
+    l_exit= iwsql_dll_load(&l_error, &(*io_session).m_dll, i_module);
 
     if (l_exit) 
     {
@@ -152,14 +185,12 @@ database_session_connect(
 
   }while(0);
 
-  driver_config_discharge(&l_driver);
-
   if (l_error)
   {
     g_propagate_error(o_error, l_error);
   }
 
-  return l_exit;
+  return l_exit; 
 }
 
 extern void
@@ -270,3 +301,17 @@ database_session_next(
 
   return l_exit;
 }
+
+extern int
+database_session_query_show_databases(
+  GError**                              o_error,
+  char***                               o_list,
+  unsigned*const                        o_slots,
+  struct database_session*const         io_session)
+{
+  int                                   l_exit;
+
+  l_exit= iwsql_dll_show_databases(o_error, o_list, o_slots, &(*io_session).m_dll);
+
+  return l_exit;
+}
