@@ -30,9 +30,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "global_common.h"
 
+GMutex                                  g_run_dialog_mutex;
 char*                                   g_builder_dir= 0;
 char*                                   g_database_config_filename= 0;
-char*                                   g_driver_config_filename= 0;
 GtkWindow*                              g_main_window= 0;
 char*                                   g_module_filename= 0;
 
@@ -175,64 +175,6 @@ global_common_database_config_filename_new(
   return l_exit;
 }
 
-static int
-global_common_driver_config_filename_new(
-  GError**                              o_error)
-{
-  GError*                               l_error;
-  int                                   l_exit;
-  gboolean                              l_rc;
-  gchar const*const*                    l_env;
-  unsigned                              l_slot;
-  char*                                 l_file;
-
-  l_env= g_get_system_config_dirs();
-  l_error= 0;
-  l_exit= 0;
-  l_slot= 0;
-
-  do
-  {
-
-    if (0 == l_env[l_slot])
-    {
-      l_error= g_error_new(
-        GLOBAL,
-        GLOBAL_DRIVER_CONFIG_NOTFOUND,
-        "Unable to find driver config 'iwrite_driver.cfg'");
-      l_exit= -1;
-      break;
-    }
-
-    l_file= g_build_path(
-      G_DIR_SEPARATOR_S,
-      l_env[l_slot],
-      "iwrite_driver.cfg",
-      (char*)0);
-
-    l_rc= g_file_test(l_file, G_FILE_TEST_IS_REGULAR);
-
-    if (l_rc)
-    {
-      g_driver_config_filename= l_file;
-      break;
-    }
-
-    g_free(l_file);
-
-    l_slot++;
-
-  }while(1);
-
-  if (l_error)
-  {
-    _error_log(l_error);
-    g_propagate_error(o_error, l_error);
-  }
-
-  return l_exit;
-}
-
 enum create_type
 {
   create_for_console,
@@ -253,12 +195,10 @@ global_common_create(
 
   do
   {
+    
+    g_mutex_init(&g_run_dialog_mutex);
 
-#ifdef WIN32
-
-#else
-    g_module_filename=g_strdup(i_argv[0]);
-#endif
+    g_module_filename= g_strdup(i_argv[0]);
 
     if (create_for_gui == i_create_for)
     {
@@ -277,8 +217,6 @@ global_common_create(
       break;
     }
 
-    l_exit= global_common_driver_config_filename_new(&l_error);
-
   }while(0);
 
   if (l_error)
@@ -311,6 +249,7 @@ extern void
 global_common_destroy()
 {
 
+  g_mutex_clear(&g_run_dialog_mutex);
   g_free(g_module_filename);
   g_free(g_database_config_filename);
 
