@@ -29,6 +29,7 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_date.h"
+#include "item_property.h"
 
 struct date_dialog
 {
@@ -50,292 +51,87 @@ struct date_dialog
   GtkEntry*                             m_timezone_entry;
 };
 
-static void
-item_date_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct date_dialog*                   l_date;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_date= (struct date_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_date).m_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_date).m_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_date_border_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct date_dialog*                  l_dated;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_dated= (struct date_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Border Color", get_main_window());
-
-    l_text= gtk_entry_get_text((*l_dated).m_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_dated).m_border_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_date_fill_color_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GdkRGBA                               l_color;
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct date_dialog*                   l_dated;
-  gchar*                                l_rgba;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  memset(&l_color, 0, sizeof(l_color));
-
-  do
-  {
-
-    l_dated= (struct date_dialog*)i_data;
-
-    l_dialog= gtk_color_chooser_dialog_new("Fill Color", get_main_window());
-    gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(l_dialog), 1);
-
-    l_text= gtk_entry_get_text((*l_dated).m_color_entry);
-    gdk_rgba_parse(&l_color, l_text);
-    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(l_dialog), &l_color);
-
-    l_rgba= gdk_rgba_to_string(&l_color);
-    gtk_entry_set_text((*l_dated).m_fill_color_entry, l_rgba);
-    g_free(l_rgba);
-
-  }while(0);
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-  
-  return;
-}
-
-static void
-item_date_font_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
-{
-  GtkWidget*                            l_dialog;
-  int                                   l_exit;
-  struct date_dialog*                   l_date;
-  gchar*                                l_font;
-  gchar const*                          l_text;
-
-  l_dialog= 0;
-  l_exit= 0;
-  l_font= 0;
-
-  do
-  {
-
-    l_date= (struct date_dialog*)i_data;
-
-    l_text= gtk_entry_get_text(GTK_ENTRY((*l_date).m_font_entry));
-
-    l_dialog= gtk_font_chooser_dialog_new("Font", get_main_window());
-
-    gtk_font_chooser_set_font(GTK_FONT_CHOOSER(l_dialog), l_text);
-
-    gtk_window_set_modal((GtkWindow*)l_dialog, 1);
-    l_exit= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_OK != l_exit)
-    {
-      break;
-    }
-
-    l_font= gtk_font_chooser_get_font(GTK_FONT_CHOOSER(l_dialog));
-    gtk_entry_set_text(
-      (GTK_ENTRY((*l_date).m_font_entry)),
-      l_font);
-
-  }while(0);
-
-  if (l_font)
-  {
-    g_free(l_font);
-  }
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy((GtkWidget*)l_dialog);
-  }
-
-  return;
-}
-
 static void
 item_date_bind(
-  struct date_dialog*const              o_dated,
+  struct date_dialog*const              o_dlg,
   GtkBuilder*const                      i_builder)
 {
 
-  memset(o_dated, 0, sizeof(*o_dated));
+  memset(o_dlg, 0, sizeof(*o_dlg));
 
   do
   {
 
-    (*o_dated).m_color_entry=
+    (*o_dlg).m_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "color_entry"));
 
-    (*o_dated).m_color_button=
+    (*o_dlg).m_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "color_button"));
 
     g_signal_connect(
-      (*o_dated).m_color_button,
+      (*o_dlg).m_color_button,
       "clicked",
-      G_CALLBACK(item_date_color_button_cb),
-      o_dated);
+      G_CALLBACK(item_property_color_button_cb),
+      (*o_dlg).m_color_entry);
 
-    (*o_dated).m_font_entry=
+    (*o_dlg).m_font_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "font_entry"));
 
-    (*o_dated).m_font_button=
+    (*o_dlg).m_font_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "font_button"));
 
     g_signal_connect(
-      (*o_dated).m_font_button,
+      (*o_dlg).m_font_button,
       "clicked",
-      G_CALLBACK(item_date_font_button_cb),
-      o_dated);
+      G_CALLBACK(item_property_font_button_cb),
+      (*o_dlg).m_font_entry);
 
-    (*o_dated).m_border_checkbutton=
+    (*o_dlg).m_border_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "border_checkbutton"));
 
-    (*o_dated).m_border_style_comboboxtext=
+    (*o_dlg).m_border_style_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "border_style_comboboxtext"));
 
-    (*o_dated).m_border_thickness_spinbutton=
+    (*o_dlg).m_border_thickness_spinbutton=
       GTK_SPIN_BUTTON(gtk_builder_get_object(i_builder, "border_thickness_spinbutton"));
 
-    (*o_dated).m_border_color_entry=
+    (*o_dlg).m_border_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "border_color_entry"));
 
-    (*o_dated).m_border_color_button=
+    (*o_dlg).m_border_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "border_color_button"));
 
     g_signal_connect(
-      (*o_dated).m_border_color_button,
+      (*o_dlg).m_border_color_button,
       "clicked",
-      G_CALLBACK(item_date_border_color_button_cb),
-      o_dated);
+      G_CALLBACK(item_property_border_color_button_cb),
+      (*o_dlg).m_border_color_entry);
 
-    (*o_dated).m_fill_color_checkbutton=
+    (*o_dlg).m_fill_color_checkbutton=
       GTK_CHECK_BUTTON(gtk_builder_get_object(i_builder, "fill_color_checkbutton"));
 
-    (*o_dated).m_fill_color_button=
+    (*o_dlg).m_fill_color_button=
       GTK_BUTTON(gtk_builder_get_object(i_builder, "fill_color_button"));
 
-    g_signal_connect(
-      (*o_dated).m_fill_color_button,
-      "clicked",
-      G_CALLBACK(item_date_fill_color_button_cb),
-      o_dated);
-
-    (*o_dated).m_fill_color_entry=
+    (*o_dlg).m_fill_color_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "fill_color_entry"));
 
-    (*o_dated).m_date_comboboxtext=
+    g_signal_connect(
+      (*o_dlg).m_fill_color_button,
+      "clicked",
+      G_CALLBACK(item_property_fill_color_button_cb),
+      (*o_dlg).m_fill_color_entry);
+
+    (*o_dlg).m_date_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "date_comboboxtext"));
 
-    (*o_dated).m_time_comboboxtext=
+    (*o_dlg).m_time_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "time_comboboxtext"));
 
-    (*o_dated).m_locale_entry=
+    (*o_dlg).m_locale_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "locale_entry"));
 
-    (*o_dated).m_timezone_entry=
+    (*o_dlg).m_timezone_entry=
       GTK_ENTRY(gtk_builder_get_object(i_builder, "timezone_entry"));
 
   }while(0);
@@ -345,63 +141,63 @@ item_date_bind(
 
 static void
 item_date_set_values(
-  struct date_dialog*const              i_dated,
+  struct date_dialog*const              io_dlg,
   struct item_date const*const          i_date)
 {
   gchar*                                l_color;
   gchar*                                l_font;
 
   l_color= gdk_rgba_to_string(&(*i_date).m_color);
-  gtk_entry_set_text((*i_dated).m_color_entry, l_color);
+  gtk_entry_set_text((*io_dlg).m_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   l_font= pango_font_description_to_string((*i_date).m_font);
-  gtk_entry_set_text((*i_dated).m_font_entry, l_font);
+  gtk_entry_set_text((*io_dlg).m_font_entry, l_font);
   g_free(l_font);
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_dated).m_border_checkbutton),
+    GTK_TOGGLE_BUTTON((*io_dlg).m_border_checkbutton),
     (*i_date).m_border.m_active);
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_dated).m_border_style_comboboxtext), 
+      GTK_COMBO_BOX((*io_dlg).m_border_style_comboboxtext), 
       (*i_date).m_border.m_style);
 
   gtk_spin_button_set_value(
-    GTK_SPIN_BUTTON((*i_dated).m_border_thickness_spinbutton),
+    GTK_SPIN_BUTTON((*io_dlg).m_border_thickness_spinbutton),
     (*i_date).m_border.m_thickness);
 
   l_color= gdk_rgba_to_string(&(*i_date).m_border.m_color);
-  gtk_entry_set_text((*i_dated).m_border_color_entry, l_color);
+  gtk_entry_set_text((*io_dlg).m_border_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_toggle_button_set_active(
-    GTK_TOGGLE_BUTTON((*i_dated).m_fill_color_checkbutton),
+    GTK_TOGGLE_BUTTON((*io_dlg).m_fill_color_checkbutton),
     (*i_date).m_fill.m_active);
 
   l_color= gdk_rgba_to_string(&(*i_date).m_fill.m_color);
-  gtk_entry_set_text((*i_dated).m_fill_color_entry, l_color);
+  gtk_entry_set_text((*io_dlg).m_fill_color_entry, l_color);
   g_free(l_color);
   l_color= 0;
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_dated).m_date_comboboxtext), 
+      GTK_COMBO_BOX((*io_dlg).m_date_comboboxtext), 
       (*i_date).m_date_style);
 
   gtk_combo_box_set_active(
-      GTK_COMBO_BOX((*i_dated).m_time_comboboxtext), 
+      GTK_COMBO_BOX((*io_dlg).m_time_comboboxtext), 
       (*i_date).m_time_style);
 
   if ((*i_date).m_locale)
   {
-    gtk_entry_set_text((*i_dated).m_locale_entry, (*i_date).m_locale);
+    gtk_entry_set_text((*io_dlg).m_locale_entry, (*i_date).m_locale);
   }
 
   if ((*i_date).m_timezone)
   {
-    gtk_entry_set_text((*i_dated).m_timezone_entry, (*i_date).m_timezone);
+    gtk_entry_set_text((*io_dlg).m_timezone_entry, (*i_date).m_timezone);
   }
 
   return;
@@ -409,89 +205,89 @@ item_date_set_values(
 
 static void
 item_date_copy_values(
-  struct item_date *const               io_date,
-  struct date_dialog const*const        i_dated)
+  struct item_date *const               io_object,
+  struct date_dialog const*const        i_dlg)
 {
   gchar const*                          l_text;
   gint                                  l_rc;
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_color_entry));
-  gdk_rgba_parse(&(*io_date).m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_color_entry));
+  gdk_rgba_parse(&(*io_object).m_color, l_text);
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_font_entry));
-  if ((*io_date).m_font)
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_font_entry));
+  if ((*io_object).m_font)
   {
-    pango_font_description_free((*io_date).m_font);
+    pango_font_description_free((*io_object).m_font);
   }
-  (*io_date).m_font= pango_font_description_from_string(l_text);
+  (*io_object).m_font= pango_font_description_from_string(l_text);
 
-  (*io_date).m_border.m_active=
+  (*io_object).m_border.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_dated).m_border_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_border_checkbutton));
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_dated).m_border_style_comboboxtext));
+    GTK_COMBO_BOX((*i_dlg).m_border_style_comboboxtext));
 
-  if ((0 <= l_rc) && (LINE_STYLE_SLOTS > l_rc))
+  if ((0 <= l_rc) && (line_style_last > l_rc))
   {
-    (*io_date).m_border.m_style= (enum line_style_type)l_rc;
+    (*io_object).m_border.m_style= (enum line_style_type)l_rc;
   }
   else
   {
-    (*io_date).m_border.m_style= line_style_solid;
+    (*io_object).m_border.m_style= line_style_solid;
   }
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_border_color_entry));
-  gdk_rgba_parse(&(*io_date).m_border.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_border_color_entry));
+  gdk_rgba_parse(&(*io_object).m_border.m_color, l_text);
 
-  (*io_date).m_border.m_thickness= gtk_spin_button_get_value(
-    GTK_SPIN_BUTTON((*i_dated).m_border_thickness_spinbutton));
+  (*io_object).m_border.m_thickness= gtk_spin_button_get_value(
+    GTK_SPIN_BUTTON((*i_dlg).m_border_thickness_spinbutton));
 
-  (*io_date).m_fill.m_active=
+  (*io_object).m_fill.m_active=
     gtk_toggle_button_get_active(
-      GTK_TOGGLE_BUTTON((*i_dated).m_fill_color_checkbutton));
+      GTK_TOGGLE_BUTTON((*i_dlg).m_fill_color_checkbutton));
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_fill_color_entry));
-  gdk_rgba_parse(&(*io_date).m_fill.m_color, l_text);
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_fill_color_entry));
+  gdk_rgba_parse(&(*io_object).m_fill.m_color, l_text);
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_dated).m_date_comboboxtext));
+    GTK_COMBO_BOX((*i_dlg).m_date_comboboxtext));
 
   if (0 <= l_rc)
   {
-    (*io_date).m_date_style= (enum date_style_type)l_rc;
+    (*io_object).m_date_style= (enum date_style_type)l_rc;
   }
 
   l_rc = gtk_combo_box_get_active(
-    GTK_COMBO_BOX((*i_dated).m_time_comboboxtext));
+    GTK_COMBO_BOX((*i_dlg).m_time_comboboxtext));
 
   if (0 <= l_rc)
   {
-    (*io_date).m_time_style= (enum date_style_type)l_rc;
+    (*io_object).m_time_style= (enum date_style_type)l_rc;
   }
 
-  if ((*io_date).m_locale)
+  if ((*io_object).m_locale)
   {
-    g_free((*io_date).m_locale);
-    (*io_date).m_locale= 0;
+    g_free((*io_object).m_locale);
+    (*io_object).m_locale= 0;
   }
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_locale_entry));
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_locale_entry));
   if (l_text[0])
   {
-    (*io_date).m_locale= g_strdup(l_text);
+    (*io_object).m_locale= g_strdup(l_text);
   }
 
-  if ((*io_date).m_timezone)
+  if ((*io_object).m_timezone)
   {
-    g_free((*io_date).m_timezone);
-    (*io_date).m_timezone= 0;
+    g_free((*io_object).m_timezone);
+    (*io_object).m_timezone= 0;
   }
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dated).m_timezone_entry));
+  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_timezone_entry));
   if (l_text[0])
   {
-    (*io_date).m_timezone= g_strdup(l_text);
+    (*io_object).m_timezone= g_strdup(l_text);
   }
 
   return;
@@ -499,15 +295,15 @@ item_date_copy_values(
 
 extern int
 item_date_property(
-  struct item_date*const                io_date)
+  struct item_date*const                io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
-  GtkGrid*                              l_grid;
+  struct date_dialog                    l_dlg;
   GError*                               l_error;
   int                                   l_exit;
-  struct date_dialog                    l_date;
+  GtkGrid*                              l_grid;
   int                                   l_rc;
 
   l_builder= 0;
@@ -541,9 +337,9 @@ item_date_property(
       break;
     }
 
-    item_date_bind(&l_date, l_builder);
+    item_date_bind(&l_dlg, l_builder);
 
-    item_date_set_values(&l_date, io_date);
+    item_date_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Special Edit",
@@ -570,7 +366,7 @@ item_date_property(
       break;
     }
 
-    item_date_copy_values(io_date, &l_date);
+    item_date_copy_values(io_object, &l_dlg);
 
   }while(0);
 
