@@ -29,43 +29,38 @@ NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "item_fbarcode.h"
-#include "database_field.h"
-#include "mainw.h"
+#include "item_property.h"
 
 struct fbarcode_dialog
 {
   GtkComboBoxText*                      m_symbology_comboboxtext;
   GtkSpinButton*                        m_scale_spinbutton;
-  GtkEntry*                             m_field_entry;
-  GtkButton*                            m_field_button;
+  struct item_table_dialog              m_table;
 };
 
 static void
-item_fbarcode_field_button_cb(
-  GtkWidget *                           i_widget,
-  gpointer                              i_data)
+item_fbarcode_load_symbology(
+  struct fbarcode_dialog*const          o_dlg)
 {
-  struct fbarcode_dialog*               l_dlg;
-  char*                                 l_attribute;
+  unsigned                              l_slot;
 
-  l_attribute= 0;
+  l_slot= 0;
 
-  l_dlg= (struct fbarcode_dialog*)i_data;
-
-  database_field_property(
-    &l_attribute, 
-    &(*g_mainw).m_report.m_aspect,
-    &(*g_mainw).m_report.m_query);
-
-  if (l_attribute)
+  do
   {
-    gtk_entry_set_text((*l_dlg).m_field_entry, l_attribute);
-  }
 
-  if (l_attribute)
-  {
-    g_free(l_attribute);
-  }
+    if (0 == g_symtab[l_slot].m_name)
+    {
+      break;
+    }
+
+    gtk_combo_box_text_append_text(
+      (*o_dlg).m_symbology_comboboxtext,
+      g_symtab[l_slot].m_name);
+
+    l_slot++;
+
+  }while(1);
 
   return;
 }
@@ -75,7 +70,6 @@ item_fbarcode_bind(
   struct fbarcode_dialog*const          o_dlg,
   GtkBuilder*const                      i_builder)
 {
-  unsigned                              l_slot;
 
   memset(o_dlg, 0, sizeof(*o_dlg));
 
@@ -85,38 +79,24 @@ item_fbarcode_bind(
     (*o_dlg).m_symbology_comboboxtext=
       GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "symbology_comboboxtext"));
 
+    item_fbarcode_load_symbology(o_dlg);
+
     (*o_dlg).m_scale_spinbutton=
       GTK_SPIN_BUTTON(gtk_builder_get_object(i_builder, "scale_spinbutton"));
 
-    (*o_dlg).m_field_entry=
-      GTK_ENTRY(gtk_builder_get_object(i_builder, "field_entry"));
+    (*o_dlg).m_table.m_query_comboboxtext=
+      GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "query_comboboxtext"));
 
-    (*o_dlg).m_field_button=
-      GTK_BUTTON(gtk_builder_get_object(i_builder, "field_button"));
+    (*o_dlg).m_table.m_column_comboboxtext=
+      GTK_COMBO_BOX_TEXT(gtk_builder_get_object(i_builder, "column_comboboxtext"));
+
+    item_property_load_query((*o_dlg).m_table.m_query_comboboxtext);
 
     g_signal_connect(
-      (*o_dlg).m_field_button,
-      "clicked",
-      G_CALLBACK(item_fbarcode_field_button_cb),
-      o_dlg);
-
-    l_slot= 0;
-
-    do
-    {
-
-      if (0 == g_symtab[l_slot].m_name)
-      {
-        break;
-      }
-
-      gtk_combo_box_text_append_text(
-        (*o_dlg).m_symbology_comboboxtext,
-        g_symtab[l_slot].m_name);
-
-      l_slot++;
-
-    }while(1);
+      (*o_dlg).m_table.m_query_comboboxtext,
+      "changed",
+      G_CALLBACK(item_property_comboboxtext_cb),
+      &(*o_dlg).m_table);
 
   }while(0);
 
@@ -126,30 +106,32 @@ item_fbarcode_bind(
 static void
 item_fbarcode_set_values(
   struct fbarcode_dialog*const            io_dlg,
-  struct item_fbarcode const*const        i_bc)
+  struct item_fbarcode const*const        i_object)
 {
   int                                     l_index;
 
-  l_index= symbology_lookup_by_type((*i_bc).m_barcode);
+  l_index= symbology_lookup_by_type((*i_object).m_barcode);
 
   if (-1 != l_index)
   {
     gtk_combo_box_set_active(GTK_COMBO_BOX((*io_dlg).m_symbology_comboboxtext), l_index);
   }
 
-  gtk_spin_button_set_value((*io_dlg).m_scale_spinbutton, (*i_bc).m_scale);
+  item_property_database_set_active(
+    (*io_dlg).m_table.m_query_comboboxtext,
+    (*io_dlg).m_table.m_column_comboboxtext,
+    &(*i_object).m_table);
 
-  gtk_entry_set_text((*io_dlg).m_field_entry, (*i_bc).m_tag);
+  gtk_spin_button_set_value((*io_dlg).m_scale_spinbutton, (*i_object).m_scale);
 
   return;
 }
 
 static void
 item_fbarcode_copy_values(
-  struct item_fbarcode *const              io_bc,
-  struct fbarcode_dialog const*const       i_dlg)
+  struct item_fbarcode *const           io_object,
+  struct fbarcode_dialog const*const    i_dlg)
 {
-  gchar const*                          l_text;
   gint                                  l_rc;
 
   l_rc= gtk_combo_box_get_active(
@@ -157,40 +139,43 @@ item_fbarcode_copy_values(
   
   if (0 <= l_rc)
   {
-    (*io_bc).m_barcode= g_symtab[l_rc].m_type;
+    (*io_object).m_barcode= g_symtab[l_rc].m_type;
   }
   else
   {
-    (*io_bc).m_barcode= BARCODE_UNKOWN;
+    (*io_object).m_barcode= BARCODE_UNKOWN;
   }
 
-  (*io_bc).m_scale= gtk_spin_button_get_value(
+  (*io_object).m_scale= gtk_spin_button_get_value(
     GTK_SPIN_BUTTON((*i_dlg).m_scale_spinbutton));
 
-  if (0.50 > (*io_bc).m_scale)
+  if (0.50 > (*io_object).m_scale)
   {
-    (*io_bc).m_scale= 0.50;
+    (*io_object).m_scale= 0.50;
   }
 
-  l_text= gtk_entry_get_text(GTK_ENTRY((*i_dlg).m_field_entry));
-  memset((*io_bc).m_tag, 0, sizeof((*io_bc).m_tag));
-  strncpy((*io_bc).m_tag, l_text, sizeof((*io_bc).m_tag)-1);
-  g_strstrip((*io_bc).m_tag);
+  g_free((*io_object).m_table.m_query);
+  (*io_object).m_table.m_query= 
+    gtk_combo_box_text_get_active_text((*i_dlg).m_table.m_query_comboboxtext);
+
+  g_free((*io_object).m_table.m_column);
+  (*io_object).m_table.m_column= 
+    gtk_combo_box_text_get_active_text((*i_dlg).m_table.m_column_comboboxtext);
 
   return;
 }
 
 extern int
 item_fbarcode_property(
-  struct item_fbarcode*const            io_fbarcode)
+  struct item_fbarcode*const            io_object)
 {
   GtkBox*                               l_box;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
-  GtkGrid*                              l_grid;
+  struct fbarcode_dialog                l_dlg;
   GError*                               l_error;
   int                                   l_exit;
-  struct fbarcode_dialog                l_fbarcode;
+  GtkGrid*                              l_grid;
   int                                   l_rc;
 
   l_builder= 0;
@@ -224,9 +209,9 @@ item_fbarcode_property(
       break;
     }
 
-    item_fbarcode_bind(&l_fbarcode, l_builder);
+    item_fbarcode_bind(&l_dlg, l_builder);
 
-    item_fbarcode_set_values(&l_fbarcode, io_fbarcode);
+    item_fbarcode_set_values(&l_dlg, io_object);
 
     l_dialog= GTK_DIALOG(gtk_dialog_new_with_buttons(
       "Barcode Edit",
@@ -253,7 +238,7 @@ item_fbarcode_property(
       break;
     }
 
-    item_fbarcode_copy_values(io_fbarcode, &l_fbarcode);
+    item_fbarcode_copy_values(io_object, &l_dlg);
 
   }while(0);
 
