@@ -267,12 +267,13 @@ iwr_page_key_press(
 
   if (key_action_move == l_action)
   {
+    mainw_cmd_push(g_mainw, IWR_PAGE(i_widget), cmd_move);
     item_selected_move(&(*l_priv).m_item, &l_delta);
     l_redraw= 1;
   }
   else if (key_action_resize == l_action)
   {
- 
+    mainw_cmd_push(g_mainw, IWR_PAGE(i_widget), cmd_resize);
     l_resize.m_delta_x= l_delta.m_pos_x;
     l_resize.m_delta_y= l_delta.m_pos_y;
     l_resize.m_type= l_type;
