@@ -102,15 +102,15 @@ break_property_addbutton_cb(
   GtkWidget *                           i_widget,
   gpointer                              i_data)
 {
-  struct break_dialog*                  l_bd;
+  struct break_dialog*                  l_dlg;
   gchar const*                          l_text;
 
-  l_bd= (struct break_dialog*)i_data;
-  l_text= gtk_entry_get_text((*l_bd).m_group_entry);
+  l_dlg= (struct break_dialog*)i_data;
+  l_text= gtk_entry_get_text((*l_dlg).m_group_entry);
 
   if ((l_text) && l_text[0])
   {
-    break_property_group_add(l_bd, l_text);
+    break_property_group_add(l_dlg, l_text);
   }
 
   return;
@@ -121,18 +121,18 @@ break_property_removebutton_cb(
   GtkWidget *                           i_widget,
   gpointer                              i_user_data)
 {
-  struct break_dialog*                  l_bd;
+  struct break_dialog*                  l_dlg;
   GtkTreeIter                           l_iter;
   int                                   l_rc;
   GtkTreeSelection*                     l_selection;
   GtkListStore*                         l_store;
 
-  l_bd= (struct break_dialog*)i_user_data;
+  l_dlg= (struct break_dialog*)i_user_data;
 
   do
   {
 
-    l_selection= gtk_tree_view_get_selection((*l_bd).m_tree_view);
+    l_selection= gtk_tree_view_get_selection((*l_dlg).m_tree_view);
 
     l_rc= gtk_tree_selection_get_selected(l_selection, 0, &l_iter);
 
@@ -141,7 +141,7 @@ break_property_removebutton_cb(
       break;
     }
 
-    l_store= GTK_LIST_STORE((*l_bd).m_tree_model);
+    l_store= GTK_LIST_STORE((*l_dlg).m_tree_model);
     gtk_list_store_remove(l_store, &l_iter);
 
   }while(0);
@@ -201,11 +201,14 @@ break_property_set_values(
 {
   unsigned                              l_slot;
 
-  gtk_entry_set_text((*io_bd).m_page_entry, (*i_layout).m_page_break.m_tag);
+  if ((*i_layout).m_page_break.m_column)
+  {
+    gtk_entry_set_text((*io_bd).m_page_entry, (*i_layout).m_page_break.m_column);
+  }
 
   for(l_slot= 0; (*i_layout).m_group_slots > l_slot ; l_slot++)
   {
-    break_property_group_add(io_bd, (*i_layout).m_group[l_slot].m_break.m_tag);
+    break_property_group_add(io_bd, (*i_layout).m_group[l_slot].m_break.m_column);
   }
 
   return;
@@ -226,7 +229,7 @@ break_group_lookup(
   for (l_slot=0; (*io_layout).m_group_slots > l_slot; l_slot++, (*o_index)++)
   {
 
-    l_found= (0 == strcmp((*io_layout).m_group[l_slot].m_break.m_tag, i_tag));
+    l_found= (0 == strcmp((*io_layout).m_group[l_slot].m_break.m_column, i_tag));
 
     if (l_found)
     {
@@ -307,7 +310,7 @@ break_groups_remove(
     l_found= break_list_lookup(
       i_list,
       i_list_slots,
-      (*io_layout).m_group[l_group_slot].m_break.m_tag);
+      (*io_layout).m_group[l_group_slot].m_break.m_column);
 
     if (l_found)
     {
@@ -404,22 +407,14 @@ break_group_new(
       continue;
     }
 
-    strncpy(
-      (*l_group).m_break.m_tag,
-      i_list[l_slot],
-      sizeof((*l_group).m_break.m_tag));
+    g_free((*l_group).m_break.m_column);
+    (*l_group).m_break.m_column= g_strdup(i_list[l_slot]);
 
-    snprintf(
-      (*l_group).m_header.m_tag,
-      sizeof((*l_group).m_header.m_tag),
-      "%s.Header",
-      i_list[l_slot]);
+    g_free((*l_group).m_header.m_label);
+    (*l_group).m_header.m_label= g_strdup_printf("%s.Header", i_list[l_slot]);
 
-    snprintf(
-      (*l_group).m_footer.m_tag,
-      sizeof((*l_group).m_footer.m_tag),
-      "%s.Footer",
-      i_list[l_slot]);
+    g_free((*l_group).m_footer.m_label);
+    (*l_group).m_footer.m_label= g_strdup_printf("%s.Footer", i_list[l_slot]);
 
     (*l_group).m_header.m_page= IWR_PAGE(iwr_page_new());
     iwr_page_set_section_type((*l_group).m_header.m_page, section_group_header);
@@ -540,7 +535,7 @@ break_groups_add(
 
     l_slot--;
 
-    l_widget= gtk_button_new_with_label(l_break[l_slot].m_division.m_footer.m_tag);
+    l_widget= gtk_button_new_with_label(l_break[l_slot].m_division.m_footer.m_label);
     gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
     gtk_widget_set_sensitive(l_widget, 0);
     gtk_grid_insert_row((*io_layout).m_grid, l_row);
@@ -566,7 +561,7 @@ break_groups_add(
 
   for (l_slot= 0; i_list_slots > l_slot; l_slot++)
   {
-    l_widget= gtk_button_new_with_label(l_break[l_slot].m_division.m_header.m_tag);
+    l_widget= gtk_button_new_with_label(l_break[l_slot].m_division.m_header.m_label);
     gtk_button_set_relief(GTK_BUTTON(l_widget), GTK_RELIEF_NONE);
     gtk_widget_set_sensitive(l_widget, 0);
     gtk_grid_insert_row((*io_layout).m_grid, l_row);
@@ -611,19 +606,14 @@ break_property_copy_values(
   l_list= 0;
   l_list_slots= 0;
   
-  memset(
-    (*io_layout).m_page_break.m_tag, 
-    0, 
-    sizeof((*io_layout).m_page_break.m_tag));
-
   l_textc= gtk_entry_get_text((*i_bd).m_page_entry);
 
+  g_free((*io_layout).m_page_break.m_column);
+  (*io_layout).m_page_break.m_column= 0;
+
   if (l_textc && l_textc[0])
   {
-    strncpy(
-      (*io_layout).m_page_break.m_tag,
-      l_textc,
-      sizeof((*io_layout).m_page_break.m_tag)-1);
+    (*io_layout).m_page_break.m_column= g_strdup(l_textc);
   }
 
   do
@@ -718,9 +708,9 @@ break_property_create_model_view(
 
 extern int
 layout_break_property(
-  struct layout*const                     io_layout)
+  struct layout*const                   io_layout)
 {
-  struct break_dialog                   l_bd;
+  struct break_dialog                   l_dlg;
   GtkBuilder*                           l_builder;
   GtkDialog*                            l_dialog;
   GError*                               l_error;
@@ -731,7 +721,7 @@ layout_break_property(
   l_dialog= 0;
   l_error= 0;
   l_exit= 0;
-  memset(&l_bd, 0, sizeof(l_bd));
+  memset(&l_dlg, 0, sizeof(l_dlg));
 
   do
   {
@@ -758,9 +748,9 @@ layout_break_property(
       break;
     }
 
-    break_property_bind(&l_bd, l_builder);
-    break_property_create_model_view(&l_bd);
-    break_property_set_values(&l_bd, io_layout);
+    break_property_bind(&l_dlg, l_builder);
+    break_property_create_model_view(&l_dlg);
+    break_property_set_values(&l_dlg, io_layout);
 
     gtk_window_set_transient_for(GTK_WINDOW(l_dialog), get_main_window());
     gtk_widget_show_all(GTK_WIDGET(l_dialog));
@@ -776,7 +766,7 @@ layout_break_property(
       break;
     }
 
-    break_property_copy_values(io_layout, &l_bd);
+    break_property_copy_values(io_layout, &l_dlg);
 
   }while(0);
 
