@@ -44,6 +44,28 @@ layout_spec_assign(
   return;
 }
 
+extern void
+layout_spec_paper_convert_to_points(
+  struct layout_spec*const              io_spec)
+{
+  unsigned                              l_slot;
+
+  paper_convert_to_points(&(*io_spec).m_paper);
+  paper_convert_to_points(&(*io_spec).m_cover.m_header.m_paper);
+  paper_convert_to_points(&(*io_spec).m_cover.m_footer.m_paper);
+  paper_convert_to_points(&(*io_spec).m_report.m_header.m_paper);
+  paper_convert_to_points(&(*io_spec).m_report.m_detail.m_paper);
+  paper_convert_to_points(&(*io_spec).m_report.m_footer.m_paper);
+
+  for (l_slot= 0; (*io_spec).m_group_slots > l_slot; l_slot++)
+  {
+    paper_convert_to_points(&(*io_spec).m_group[l_slot].m_header.m_paper);
+    paper_convert_to_points(&(*io_spec).m_group[l_slot].m_footer.m_paper);
+  }
+
+  return;
+}
+
 static void
 layout_spec_division_sync_paper(
   struct layout_spec_division*const     io_division,
