@@ -87,6 +87,10 @@ extern void
 layout_spec_assign(
   struct layout_spec*const              o_layout);
 
+extern void
+layout_spec_paper_convert_to_points(
+  struct layout_spec*const              io_spec);
+
 extern void
 layout_spec_discharge(
   struct layout_spec*const              io_layout);
