@@ -30,6 +30,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "menu.h"
 #include "layout.h"
+#include "option.h"
+
+#ifdef WIN32
+#include <windows.h>
+#endif
 
 #define WINDOW_WIDTH                    612
 #define WINDOW_HEIGHT                   640
@@ -506,160 +511,6 @@ mainw_open(
   return l_exit;
 }
 
-extern int
-mainw_run(
-  struct mainw*const                    io_mainw)
-{
-  GtkFileChooser*                       l_chooser;
-  GtkWidget*                            l_dialog;
-  GError*                               l_error;
-  int                                   l_exit;
-  char*                                 l_filename;
-  GtkFileFilter*                        l_filter;
-  struct goop                           l_goop;
-  char*                                 l_ptr;
-  int                                   l_rc;
-  unsigned                              l_size;
-
-  l_error= 0;
-  l_exit= -1;
-  l_dialog= 0;
-  l_filename= 0;
-  l_filter= 0;
-  memset(&l_goop, 0, sizeof(l_goop));
-  
-  do
-  {
-
-    l_exit= mainw_save(io_mainw);
-
-    if (l_exit)
-    {
-      break;
-    }
-    
-    l_dialog = gtk_file_chooser_dialog_new(
-      "Save File",
-      (*io_mainw).m_window,
-      GTK_FILE_CHOOSER_ACTION_SAVE,
-      "_Cancel",
-      GTK_RESPONSE_CANCEL,
-      "_Save",
-      GTK_RESPONSE_ACCEPT,
-      NULL);
-
-    l_chooser= GTK_FILE_CHOOSER(l_dialog);
-    
-    if ((*io_mainw).m_report.m_reportfile)
-    {
-      l_size= strlen((*io_mainw).m_report.m_reportfile);
-      l_filename= (char*)g_malloc0(5+l_size);
-      memcpy(l_filename, (*io_mainw).m_report.m_reportfile, l_size);
-      l_ptr= strrchr(l_filename, '.');
-      if (0 == l_ptr)
-      {
-        l_ptr= l_filename+l_size;
-      }
-      switch ((*io_mainw).m_report.m_style)
-      {
-        case style_layout:
-          memcpy(l_ptr, ".pdf\0", 5);
-          break;
-        case style_export:
-          memcpy(l_ptr, ".csv\0", 5);
-          break;
-        default:
-          break;
-      } 
-      gtk_file_chooser_set_filename(l_chooser, l_filename);
-      g_free(l_filename);
-      l_filename= 0;
-    }
-    else
-    {
-      switch ((*io_mainw).m_report.m_style)
-      {
-        case style_label:
-          /* fall through */
-        case style_layout:
-          gtk_file_chooser_set_current_name(l_chooser, "report.pdf");
-          break;
-        case style_export:
-          gtk_file_chooser_set_current_name(l_chooser, "report.csv");
-          break;
-        default:
-          break;
-      } 
-    }
-
-    switch ((*io_mainw).m_report.m_style)
-    {
-      case style_layout:
-      /* fall through */
-      case style_label:
-        l_filter= gtk_file_filter_new();
-        gtk_file_filter_add_pattern(l_filter, "*.pdf");
-        gtk_file_filter_set_name(l_filter, "PDF");
-        gtk_file_chooser_add_filter(l_chooser, l_filter);
-        break;
-      case style_export:
-        l_filter= gtk_file_filter_new();
-        gtk_file_filter_add_pattern(l_filter, "*.csv");
-        gtk_file_filter_set_name(l_filter, "CSV");
-        gtk_file_chooser_add_filter(l_chooser, l_filter);
-        break;
-      default:
-        break;
-    }
-
-    l_rc= gtk_dialog_run(GTK_DIALOG(l_dialog));
-
-    if (GTK_RESPONSE_ACCEPT != l_rc)
-    {
-      break;
-    }
-
-    l_filename= gtk_file_chooser_get_filename(l_chooser);
-    gtk_widget_destroy(GTK_WIDGET(l_dialog));
-    l_dialog= 0;
-
-    l_goop.m_interactive= 1;
-    l_goop.m_outputfile= l_filename;
-
-    l_exit= report_util_run(
-      &l_error,
-      (*io_mainw).m_report.m_reportfile, 
-      (*io_mainw).m_report.m_aspect.m_password,
-      &l_goop);
-
-    if (l_exit)
-    {
-      break;
-    }
-
-    mainw_xdg_open_file(l_filename);
-
-  }while(0);
-
-  if (l_filename)
-  {
-    g_free(l_filename);
-  }
-
-  if (l_dialog)
-  {
-    gtk_widget_destroy(GTK_WIDGET(l_dialog));
-  }
-
-  if (l_error)
-  {
-    _error_display_prompt(l_error); 
-    g_clear_error(&l_error);
-  }
-
-  return l_exit;
-}
-
 extern int
 mainw_save(
   struct mainw*const                    io_mainw)
@@ -720,7 +571,7 @@ mainw_save_as(
   {
     
     l_dialog = gtk_file_chooser_dialog_new(
-      "Save File",
+      "Save Report",
       (*io_mainw).m_window,
       GTK_FILE_CHOOSER_ACTION_SAVE,
       "_Cancel",
@@ -769,6 +620,92 @@ mainw_save_as(
   return l_exit;
 }
 
+#ifdef WIN32
+extern int
+mainw_xdg_open_file(
+  char const*                           i_filename)
+{
+  GtkDialog*                            l_dialog;
+  int                                   l_exit;
+  HINSTANCE                             l_instance;
+  char const*                           l_msg;
+
+  l_exit= 0;
+
+  do
+  {
+
+    l_instance= ShellExecuteA(0, 0, i_filename, 0, 0, SW_SHOW);
+
+    if (32 < (int)(ptrdiff_t)l_instance)
+    {
+      break;
+    }
+
+    /* call FormatMessage() ? */
+    switch((int)(ptrdiff_t)l_instance)
+    {
+      case 0: 
+        l_msg= "The operating system is out of memory or resources.";
+        break;
+      case ERROR_FILE_NOT_FOUND:
+        l_msg= "File not found";
+        break;
+      case ERROR_PATH_NOT_FOUND:
+        l_msg= "The specified path was not found";
+        break;
+      case ERROR_BAD_FORMAT:
+        l_msg= "Inavlid file format";
+        break;
+      case SE_ERR_ACCESSDENIED:
+        l_msg= "The operating system denied access to the specified file";
+        break;
+      case SE_ERR_ASSOCINCOMPLETE:
+        l_msg= "The file name association is incomplete or invalid";
+        break;
+      case SE_ERR_DDEBUSY:
+        l_msg= "The DDE transaction could not be completed";
+        break;
+      case SE_ERR_DDEFAIL:
+        l_msg= "The DDE transaction failed";
+        break;
+      case SE_ERR_DDETIMEOUT:
+        l_msg= "Request timed out";
+        break;
+      case SE_ERR_DLLNOTFOUND:
+        l_msg= "The specified DLL was not found";
+        break;
+      case SE_ERR_NOASSOC:
+        l_msg= "There is no application associated with the given file";
+        break;
+      case SE_ERR_OOM:
+        l_msg= "There was not enough memory to complete the operation";
+      case SE_ERR_SHARE:
+        l_msg= "A sharing violation occurred";
+        break;
+      default:
+        l_msg= "Unknown";
+        break;
+    }
+
+    l_dialog= GTK_DIALOG(gtk_message_dialog_new(
+      get_main_window(),
+      GTK_DIALOG_MODAL,
+      GTK_MESSAGE_ERROR,
+      GTK_BUTTONS_CLOSE,
+      "Unable to launch file '%s': %s(%d)",
+      i_filename,
+      l_msg,
+      (int)(ptrdiff_t)l_instance));
+    gtk_dialog_run(l_dialog);
+    gtk_widget_destroy(GTK_WIDGET(l_dialog));
+    l_exit= -1;
+
+  }while(0);
+
+  return l_exit;
+}
+#else
 extern int
 mainw_xdg_open_file(
   char const*                           i_filename)
@@ -806,3 +743,4 @@ mainw_xdg_open_file(
 
   return !l_exit;
 }
+#endif
