@@ -31,6 +31,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #ifndef __mainw_h__
 
 #include "global_common.h"
+#include "copybuf.h"
+#include "cmd.h"
 #include "database_session.h"
 #include "export_csv.h"
 #include "iwr_page.h"
@@ -40,6 +42,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 struct mainw
 {
+  struct copybuf                        m_copybuf;
+  struct cmd                            m_cmd;
   GtkGrid*                              m_grid;
   GtkMenuBar*                           m_menu;
   GtkWindow*                            m_window;
@@ -54,6 +58,16 @@ extern void
 mainw_assign(
   struct mainw*const                    o_mainw);
 
+extern void
+mainw_cmd_push(
+  struct mainw*const                    io_mainw,
+  IwrPage*                              io_page,
+  enum cmd_type const                   i_type);
+
+extern void
+mainw_cmd_push_create(
+  struct mainw*const                    io_mainw);
+
 extern int
 mainw_create(
   struct mainw*const                    io_mainw);
@@ -62,6 +76,34 @@ extern void
 mainw_discharge(
   struct mainw*const                    io_mainw);
 
+extern void
+mainw_edit_clear(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_copy(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_cut(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_paste(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_redo(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_set_menu_state(
+  struct mainw*const                    io_mainw);
+
+extern void
+mainw_edit_undo(
+  struct mainw*const                    io_mainw);
+
 extern int
 mainw_open(
   struct mainw*const                    io_mainw,
@@ -85,6 +127,10 @@ mainw_size_allocate(
   GdkRectangle*                         i_alloc,
   gpointer                              i_user_data);
 
+extern void
+mainw_size_allocate_hack(
+  struct mainw*const                    io_mainw);
+
 extern int
 mainw_xdg_open_file(
   char const*                           i_filename);
