@@ -776,6 +776,20 @@ fsum_menuitem_activate_cb(
   return;
 }
 
+G_MODULE_EXPORT void
+report_menuitem_activate_cb(
+  GtkMenuItem *                         i_menuitem,
+  gpointer                              i_user_data)
+{
+  struct mainw*                         l_mainw;
+
+  l_mainw= (struct mainw*)i_user_data;
+  report_item_new(&(*l_mainw).m_report, item_type_report);
+  mainw_cmd_push_create(l_mainw);
+
+  return;
+}
+
 G_MODULE_EXPORT void
 text_menuitem_activate_cb(
   GtkMenuItem *                         i_menuitem,
@@ -898,6 +912,7 @@ GtkMenuItem*                            g_section_menuitem;
 GtkMenuItem*                            g_insert_menuitem;
 GtkMenuItem*                            g_break_menuitem;
 GtkMenuItem*                            g_edit_menuitem;
+GtkMenuItem*                            g_report_menuitem;
 GtkMenuItem*                            g_undo_menuitem;
 GtkMenuItem*                            g_redo_menuitem;
 GtkCheckMenuItem*                       g_highlight_menuitem;
@@ -976,6 +991,9 @@ menu_bind(
   g_edit_menuitem= GTK_MENU_ITEM(
     gtk_builder_get_object(io_builder, "edit_menuitem"));
 
+  g_report_menuitem= GTK_MENU_ITEM(
+    gtk_builder_get_object(io_builder, "report_menuitem"));
+
   g_undo_menuitem= GTK_MENU_ITEM(
     gtk_builder_get_object(io_builder, "undo_menuitem"));
   gtk_widget_set_sensitive(GTK_WIDGET(g_undo_menuitem), 0); 
@@ -1038,11 +1056,14 @@ menu_label_set_defaults()
   gtk_widget_set_sensitive(GTK_WIDGET(g_insert_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_break_menuitem), 0);
   gtk_widget_set_sensitive(GTK_WIDGET(g_edit_menuitem), 1);
+  gtk_widget_set_sensitive(GTK_WIDGET(g_report_menuitem), 0);
+
   gtk_widget_show(GTK_WIDGET(g_view_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_section_menuitem));
   gtk_widget_show(GTK_WIDGET(g_insert_menuitem));
   gtk_widget_hide(GTK_WIDGET(g_break_menuitem));
   gtk_widget_show(GTK_WIDGET(g_edit_menuitem));
+  gtk_widget_hide(GTK_WIDGET(g_report_menuitem));
 
   gtk_check_menu_item_set_active(g_highlight_menuitem, 0);
   gtk_check_menu_item_set_active(g_ruleline_horizontal_menuitem, 0);
@@ -1060,11 +1081,14 @@ menu_layout_set_defaults()
   gtk_widget_set_sensitive(GTK_WIDGET(g_insert_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_break_menuitem), 1);
   gtk_widget_set_sensitive(GTK_WIDGET(g_edit_menuitem), 1);
+  gtk_widget_set_sensitive(GTK_WIDGET(g_report_menuitem), 1);
+
   gtk_widget_show(GTK_WIDGET(g_view_menuitem));
   gtk_widget_show(GTK_WIDGET(g_section_menuitem));
   gtk_widget_show(GTK_WIDGET(g_insert_menuitem));
   gtk_widget_show(GTK_WIDGET(g_break_menuitem));
   gtk_widget_show(GTK_WIDGET(g_edit_menuitem));
+  gtk_widget_show(GTK_WIDGET(g_report_menuitem));
 
   gtk_check_menu_item_set_active(g_highlight_menuitem, 0);
   gtk_check_menu_item_set_active(g_ruleline_horizontal_menuitem, 0);
