@@ -30,6 +30,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 #include "option.h"
 #include "version.h"
+#include "wallet.h"
 
 extern void
 option_assign(
@@ -37,20 +38,12 @@ option_assign(
 {
 
   memset(o_option, 0, sizeof(*o_option));
-  (*o_option).m_prompt= g_hash_table_new(g_str_hash, g_str_equal);
 
-  return;
-}
-
-static void
-option_discharge_key(
-  gpointer                              l_key,
-  gpointer                              l_value,
-  gpointer                              l_user_data)
-{
-
-  g_free(l_key);
-  g_free(l_value);
+  (*o_option).m_prompt= g_hash_table_new_full(
+    g_str_hash,
+    g_str_equal,
+    g_free,
+    g_free);
 
   return;
 }
@@ -65,80 +58,122 @@ option_discharge(
     g_free((*io_option).m_outputfile);
   }
 
-  if ((*io_option).m_password)
-  {
-    g_free((*io_option).m_password);
-  }
-
   if ((*io_option).m_reportfile)
   {
     g_free((*io_option).m_reportfile);
   }
 
-  g_hash_table_foreach((*io_option).m_prompt, option_discharge_key, 0);
-  g_hash_table_destroy((*io_option).m_prompt);
+  if ((*io_option).m_prompt)
+  {
+    g_hash_table_destroy((*io_option).m_prompt);
+  }
 
   memset(io_option, 0, sizeof(*io_option));
 
   return;
 }
 
-static int
-option_prompt_add_hash(
-  GHashTable*                           io_prompt,
-  char *const*                          i_prompt)
+static char*
+option_password_parse(
+  char const**                          o_next,
+  char const*                           i_param)
 {
-  int                                   l_exit;
-  size_t                                l_slot;
-  char*                                 l_key;
-  char*                                 l_value;
-  char*                                 l_ptr;
-  ptrdiff_t                             l_size;
+  char*                                 l_dst;
+  size_t                                l_size;
+  char*                                 l_slice;
+  char const*                           l_src;
 
-  l_exit= 0;
+  l_src= i_param;
+  l_size= strlen(i_param);
+  l_slice= (char*)g_malloc0(1+l_size);
+  l_dst= l_slice;
 
   do
   {
-    if(0 == io_prompt)
+
+    if (0 == l_src[0])
     {
-      break; 
+      break;
     }
 
-    for(l_slot= 0; i_prompt[l_slot]; l_slot++)
+    if ('\\' == l_src[0])
     {
+      l_src++;
+    }
+    else if (':' == l_src[0])
+    {
+      l_src++;
+      break;
+    }
+  
+    l_dst[0]= l_src[0];
+    l_dst++;
+    l_src++;
 
-      l_ptr= strrchr(i_prompt[l_slot], ':');
+  }while(1);
 
-      if (l_ptr)
-      { 
-        l_size= (l_ptr - i_prompt[l_slot]);
-        l_key= (char*)malloc(1+l_size);
-        memset(l_key, 0, 1+l_size);
-        memcpy(l_key, i_prompt[l_slot], l_size);
+  (*o_next)= l_src;
 
-        l_ptr++;
-        l_size= strlen(l_ptr);
-        l_value= (char*)malloc(1+l_size);
-        memset(l_value, 0, 1+l_size);
-        memcpy(l_value, l_ptr, l_size);
+  return l_slice;
+}
 
-        g_hash_table_insert(io_prompt, l_key, l_value);
+static int
+option_prompt_add_hash(
+  GHashTable*                           io_prompt,
+  char *const*                          i_param)
+{
+  int                                   l_exit;
+  char*                                 l_key;
+  char const*                           l_next;
+  size_t                                l_slot;
+  char*                                 l_value;
 
-        if (0 == (l_key[0]) || (0 == l_value[0]))
-        { 
-          g_warning("Missing key or value: %s\n", i_prompt[l_slot]);
-          l_exit= -1;
-        }
+  l_exit= 0;
 
-      }
-      else
-      {
-        g_warning("Unable to parse command line: %s\n", i_prompt[l_slot]);
-        l_exit= -1;
-      }
+  for(l_slot= 0; i_param[l_slot]; l_slot++)
+  {
+
+    if (0 == i_param[l_slot][0])
+    {
+      continue;
     }
 
-  }while(0);
+    l_key= option_password_parse(&l_next, i_param[l_slot]);
+    l_value= option_password_parse(&l_next, l_next);
+    g_strstrip(l_key);
+    g_strstrip(l_value);
+    g_hash_table_insert(io_prompt, l_key, l_value);
+  }
+
+  return l_exit;
+}
+
+static int
+option_password_add_hash(
+  char *const*                          i_param)
+{
+  int                                   l_exit;
+  struct password*                      l_pwd;
+  size_t                                l_slot;
+  char const*                           l_next;
+
+  l_exit= 0;
+  l_slot= 0;
+
+  for (l_slot= 0; i_param[l_slot]; l_slot++)
+  {
+
+    if (0 == i_param[l_slot][0])
+    {
+      continue;
+    }
+
+    l_pwd= (struct password*)g_malloc0(sizeof(*l_pwd));
+    (*l_pwd).m_password= option_password_parse(&l_next, i_param[l_slot]);
+    (*l_pwd).m_username= option_password_parse(&l_next, l_next);
+    (*l_pwd).m_aspect= option_password_parse(&l_next, l_next);
+    wallet_insert(l_pwd);
+  }
 
   return l_exit;
 }
@@ -151,14 +186,14 @@ option_parse(
 {
   static char*                          l_format;
   static char*                          l_outputfile;
-  static char*                          l_password;
   static char**                         l_prompt;
   static char*                          l_reportfile;
+  static char**                         l_password;
   static GOptionEntry                   l_entries[]=
   {
     {"output", 0, 0, G_OPTION_ARG_FILENAME, &l_outputfile, "output file name", "outputfile"},
-    {"password", 0, 0, G_OPTION_ARG_STRING, &l_password, "database password", "password"},
-    {"prompt", 0, 0, G_OPTION_ARG_STRING_ARRAY, &l_prompt, "query prompt (--prompt=field:value", "field:value"},
+    {"password", 0, 0, G_OPTION_ARG_STRING_ARRAY, &l_password, "password", "password[:username[:aspect]]"},
+    {"prompt", 0, 0, G_OPTION_ARG_STRING_ARRAY, &l_prompt, "query prompt", "field:value"},
     {"report", 0, 0, G_OPTION_ARG_FILENAME, &l_reportfile, "report to run", "reportname"},
 /*
     {"format", 0, 0, G_OPTION_ARG_STRING, &l_format, "output format (pdf)", "pdf"},
@@ -170,6 +205,7 @@ option_parse(
   GError*                               l_error;
   int                                   l_exit;
   unsigned                              l_slot;
+  char const*                           l_stage;
   char                                  l_summary[64];
 
   l_ctx= 0;
@@ -180,18 +216,20 @@ option_parse(
   l_password= 0;
   l_prompt= 0;
   l_reportfile= 0;
+  l_stage= version_get_stage_text(g_version.m_stage);
 
   snprintf(
     l_summary,
     sizeof(l_summary),
-    "iwrite - %d.%d.%d.%d (%s%s%s)",
+    "iwrite - %d.%d.%d.%d (%s.%s.%s-%s)",
     g_version.m_major,
     g_version.m_minor,
     g_version.m_stage,
     g_version.m_micro,
     g_version.m_stamp.m_year,
     g_version.m_stamp.m_month,
-    g_version.m_stamp.m_day);
+    g_version.m_stamp.m_day,
+    l_stage);
 
   do
   {
@@ -212,7 +250,12 @@ option_parse(
 
     if (l_prompt)
     {
-      option_prompt_add_hash((*io_option).m_prompt, l_prompt);
+      l_exit|= option_prompt_add_hash((*io_option).m_prompt, l_prompt);
+    }
+
+    if (l_password)
+    {
+      l_exit|= option_password_add_hash(l_password);
     }
 
     if (0 == l_reportfile)
@@ -220,9 +263,8 @@ option_parse(
       if (l_outputfile || l_format)
       {
         g_warning("Report file missing from command line\n");
-        l_exit= -1;
+        l_exit|= -1;
       }
-      break;
     }
 
     (*io_option).m_reportfile= l_reportfile;
@@ -234,9 +276,6 @@ option_parse(
       l_outputfile= 0;
     }
 
-    (*io_option).m_password= l_password;
-    l_password= 0;
-
   }while(0);
 
   if (l_ctx)
@@ -246,11 +285,6 @@ option_parse(
 
   g_clear_error(&l_error);
 
-  if (l_format)
-  {
-    g_free(l_format);
-  }
-
   if (l_prompt)
   {
     for(l_slot= 0; l_prompt[l_slot]; l_slot++)
@@ -259,15 +293,17 @@ option_parse(
     }
   }
 
-  if (l_outputfile)
+  if (l_password)
   {
-    g_free(l_outputfile);
+    for(l_slot= 0; l_password[l_slot]; l_slot++)
+    {
+      g_free(l_password[l_slot]);
+    }
   }
 
-  if (l_reportfile)
-  {
-    g_free(l_reportfile);
-  }
+  g_free(l_format);
+  g_free(l_outputfile);
+  g_free(l_reportfile);
 
   return l_exit;
 }
