@@ -231,7 +231,7 @@ pixbuf_read(
   guchar*                               l_compr;
   gsize                                 l_compr_len;
   guchar*                               l_pixels;
-  gsize                                 l_pixels_len;
+  gulong                                l_pixels_len;
   int                                   l_rc;
 
   (*o_pixbuf)= 0;
