@@ -32,7 +32,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "global_common.h"
 #include "database_aspect.h"
-#include "goop.h"
 
 struct query_node
 {
@@ -79,27 +78,23 @@ query_first_new(
 extern void
 query_insert_after(
   struct query*const                     io_query,
-  struct query_node*const                i_node,
-  struct query_node*const                i_node_new);
+  struct query_node*const                io_node,
+  struct query_node*const                io_node_new);
 
 extern void
 query_insert_before(
   struct query*const                     io_query,
-  struct query_node*const                i_node,
-  struct query_node*const                i_node_new);
+  struct query_node*const                io_node,
+  struct query_node*const                io_node_new);
 
 extern void
 query_last_new(
   struct query_node**                   o_node,
   struct query*                         io_query);
 
-extern void
-query_list_delete(
-  struct query*                         io_query);
-
 extern void
 query_node_assign(
-  struct query_node*                    io_node);
+  struct query_node*                    o_node);
 
 extern void
 query_node_discharge(
