@@ -103,7 +103,7 @@ query_exec_node_lookup(
 
 #define PRIMARY                         0
 
-static void
+extern void
 query_exec_parse(
   struct query_exec*                    io_exec,
   struct query const*const              i_query)
@@ -617,7 +617,7 @@ query_exec_lookup(
   return;
 }
 
-static int
+extern int
 query_exec_write(
   GOutputStream*                        io_gio,
   struct query_exec_node const*const    i_sql)
@@ -699,13 +699,11 @@ query_exec_prepare(
 {
   GError*                               l_error;
   int                                   l_exit;
-  FILE*                                 l_fp;
   GOutputStream*                        l_gio;
   struct query_exec_node*               l_query;
 
   l_error= 0;
   l_exit= 0;
-  l_fp= 0;
   l_gio= 0;
 
   do
