@@ -106,7 +106,7 @@ cairo_draw_bar(cairo_t *cr,
 static int
 cairo_plot_maxi(struct zint_symbol *symbol, cairo_t *cr)
 {
-    return ERROR_ENCODING_PROBLEM;
+    return ZINT_ERROR_ENCODING_PROBLEM;
 }
 
 static int
@@ -617,27 +617,27 @@ ZBarcode_Print_Cairo(struct zint_symbol *symbol, cairo_t *cr)
 
         if (strlen(symbol->fgcolour) != 6) {
             strcpy(symbol->errtxt, "Malformed foreground colour target");
-            error_number =  ERROR_INVALID_OPTION;
+            error_number =  ZINT_ERROR_INVALID_OPTION;
             break;
         }
 
         if (strlen(symbol->bgcolour) != 6) {
             strcpy(symbol->errtxt, "Malformed background colour target");
-            error_number =  ERROR_INVALID_OPTION;
+            error_number =  ZINT_ERROR_INVALID_OPTION;
             break;
         }
 
         error_number = is_sane(SSET, (unsigned char *)symbol->fgcolour, strlen(symbol->fgcolour));
         if (error_number) {
             strcpy(symbol->errtxt, "Malformed foreground colour target");
-            error_number =  ERROR_INVALID_OPTION;
+            error_number =  ZINT_ERROR_INVALID_OPTION;
             break;
         }
 
         error_number = is_sane(SSET, (unsigned char *)symbol->bgcolour, strlen(symbol->bgcolour));
         if (error_number) {
             strcpy(symbol->errtxt, "Malformed background colour target");
-            error_number =  ERROR_INVALID_OPTION;
+            error_number =  ZINT_ERROR_INVALID_OPTION;
             break;
         }
 
